@@ -44,7 +44,7 @@ GtkWidget *dummy, *eject, *pad, *swab_audio, *dao, *no_image, *use_image;
 GtkWidget *audio_tracks, *image_path, *overburn;
 GtkWidget *copy_iso_cd, *iso_device_path, *copy_audio_cd, *audio_device_path;
 GtkWidget *blank_all, *blank_fast, *fsentry, *need_track_size, *enable_burnproof;
-GtkWidget *speed_spin, *grace_time_spin, *disable_fixate;
+GtkWidget *speed_spin, *grace_time_spin, *disable_fixate, *cdrw_force;
 char *def_image_path = NULL;
 
 /* TODO: this file is getting too large and covers to much stuff - split it */
@@ -502,11 +502,13 @@ static void config_cdrw(GtkWidget *vbox, config_cdr_data *cdr_info) {
 
 	blank_all = gtk_radio_button_new_with_label(hbox2_group, _("all"));
 	hbox2_group = gtk_radio_button_group(GTK_RADIO_BUTTON(blank_all));
+	gtk_tooltips_set_tip(tooltips, blank_all, _("Blank the entire disk. This may take a long time."), NULL);
 	gtk_widget_show(blank_all);
 	gtk_box_pack_start(GTK_BOX(hbox), blank_all, FALSE, FALSE, 0);
 
 	blank_fast = gtk_radio_button_new_with_label(hbox2_group, _("fast"));
 	hbox2_group = gtk_radio_button_group(GTK_RADIO_BUTTON(blank_fast));
+	gtk_tooltips_set_tip(tooltips, blank_fast, _("Minimally blank the disk (erases PMA, TOC and pregap)."), NULL);
 	gtk_widget_show(blank_fast);
 	gtk_box_pack_start(GTK_BOX(hbox), blank_fast, FALSE, FALSE, 0);
 
@@ -518,6 +520,16 @@ static void config_cdrw(GtkWidget *vbox, config_cdr_data *cdr_info) {
 	gtk_signal_connect(GTK_OBJECT(blank_button),
 			"clicked", (GtkSignalFunc) start_blanking, cdr_info);
 
+	cdrw_force = gtk_check_button_new_with_label(_("force"));
+	gtk_widget_show(cdrw_force);
+	gtk_box_pack_start(GTK_BOX(hbox), cdrw_force, FALSE, FALSE, 0);
+	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(cdrw_force), FALSE);
+	gtk_tooltips_set_tip(tooltips, cdrw_force,
+			_("Force to continue on some errors. cdrecord will do some tricks "
+				"in order to try to allow you to blank bad CD-RW disks. "
+				"You should probably use the \"all\" blanking method when "
+				"using this option. Use this option only when you have trouble "
+				"blanking some media!"), NULL);
 }
 
 static void start_audio_on_the_fly(GSList *cdda2wav, cmd_v *cdr, cmd_v *cdr_close) {
