@@ -27,15 +27,6 @@
 
 static char *last_cwd = NULL;
 
-gint resize_clist_col_ratio(GtkWidget *widget, GdkEvent *event, gpointer data) {
-/* FIXME: this isn't working very well to begin with, and if you consider nonstandard fontsizes it
- *        doesn't work at all */
-/*	gtk_clist_set_column_width(GTK_CLIST(data), 0,
-			GTK_WIDGET(data)->allocation.width - 100);
-	gtk_clist_set_column_width(GTK_CLIST(data), 1, 20); */
-	return FALSE;
-}
-
 static void save_file_path(GtkWidget *w, gpointer data) {
 	char *path;
 
@@ -79,11 +70,14 @@ void choose_file(GtkWidget *widget, gpointer addfunction) {
 	GtkWidget *selector;
 
 	selector = get_choose_file_widget(addfunction);
-	/* open the selector at the place we were last */
 	if (NULL != last_cwd)
 		gtk_file_selection_set_filename(GTK_FILE_SELECTION(selector), last_cwd);
 
 	gtk_widget_show(selector);
+	/* without the following call an unnecessary horizontal scrollbar
+	 * appears for the file clist (and when the fileselector is massaged in
+	 * selected_file() it disappears - this makes it disappear right away) */
+	gtk_file_selection_set_filename(GTK_FILE_SELECTION(selector), "");
 }
 
 void choose_file_at(char *path, gpointer addfunction) {
@@ -91,6 +85,7 @@ void choose_file_at(char *path, gpointer addfunction) {
 
 	selector = get_choose_file_widget(addfunction);
 	gtk_file_selection_set_filename(GTK_FILE_SELECTION(selector), path);
+
 	gtk_widget_show(selector);
 }
 
