@@ -278,6 +278,9 @@ cmd_v *make_blank_command(config_cdr_data *cdr_info) {
 		return NULL;
 	}
 
+	if (GTK_TOGGLE_BUTTON(cdrw_force)->active)
+		add_option_to_cmd(cdr_cmd, "-force");
+
 	return cdr_cmd;
 }
 
