@@ -18,17 +18,25 @@
 
 extern char *cdrecord_path;
 extern char *mkisofs_path;
-extern char *mkhybrid_path;
 extern char *diff_path;
 extern int no_of_tracks;
-extern char new_session_dir_name[];
+extern char *isocdrom_device_path;
 
 cmd_v *make_cdrecord_command(config_cdr_data *);
 cmd_v *make_blank_command(config_cdr_data *);
 cmd_v *make_mkisofs_command(int, char *, config_cdr_data *);
-cmd_v *make_mkisofs_c_optimize();
+cmd_v *make_mkisofs_c_optimize(file_data *c[], int i);
 cmd_v *make_cdrecord_read_atip_command(config_cdr_data *);
+cmd_v *make_cdrecord_trayaction_command(config_cdr_data *, guint);
 
 cmd_v *make_cdrecord_cmd_for_audio_track(config_cdr_data *);
 cmd_v *make_cdrecord_cmd_for_audio_track_fixate(config_cdr_data *);
 GSList *make_cdda2wav_list_cmd(void);
+char *get_last_session_info(config_cdr_data *);
+
+int check_if_exe_ok(char *);
+
+enum {
+	TRAY_EJECT,
+	TRAY_CLOSE
+};
