@@ -68,7 +68,7 @@ static GtkWidget *new_base_error_dialog(char *error_msg) {
 	GtkWidget *dialog, *label, *button;
 
 	dialog = gtk_dialog_new();
-	button = gtk_button_new_with_label(_("Ok"));
+	button = gtk_button_new_with_label(_("OK"));
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 			GTK_SIGNAL_FUNC(close_dialog), (gpointer) dialog);
 	label = gtk_label_new(error_msg);
@@ -83,13 +83,26 @@ static GtkWidget *new_base_error_dialog(char *error_msg) {
 
 /* Informs the user of that an error occured and let's him aknowledge it. */
 void alert_user_of_error(gchar *error_msg) {
+	g_warning("alert_user_of_error: %s\n", error_msg);
 	gtk_widget_show_all(new_base_error_dialog(error_msg));
 }
 
+void alert_user_of_error_with_cb(gchar *error_msg, GtkSignalFunc callback) {
+	GtkWidget *dialog;
+
+	g_warning("alert_user_of_error_with_cb: %s\n", error_msg);
+	dialog = new_base_error_dialog(error_msg);
+	gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
+			GTK_SIGNAL_FUNC(callback), (gpointer) dialog);
+	gtk_widget_show_all(dialog);
+}
+
 void alert_user_of_error_msg(gchar *error_msg, gchar *verbose_msg) {
 	GtkWidget *dialog;
 	GtkWidget *text, *vscrollbar, *hbox;
 
+	g_warning("alert_user_of_error_msg: %s\n", error_msg);
+	g_warning("alert_user_of_error_msg: %s\n", verbose_msg);
 	dialog = new_base_error_dialog(error_msg);
 
 	hbox = gtk_hbox_new(FALSE, 0);
@@ -151,7 +164,7 @@ config_cdr_data *config_cdr(int config_flags) {
 			GTK_SHRINK, GTK_SHRINK, 0, 0);
 	gtk_label_set_justify(GTK_LABEL(target), GTK_JUSTIFY_LEFT);
 
-	scsibus = gtk_label_new(_("Scsibus:"));
+	scsibus = gtk_label_new(_("SCSI-bus:"));
 	gtk_widget_show(scsibus);
 	gtk_table_attach(GTK_TABLE(table), scsibus, 0, 1, 0, 1,
 			GTK_SHRINK, GTK_SHRINK, 0, 0);
@@ -218,7 +231,7 @@ config_cdr_data *config_cdr(int config_flags) {
 	gtk_box_pack_start(GTK_BOX(vbox2), dev_entry, TRUE, TRUE, 0);
 	gtk_tooltips_set_tip(tooltips, dev_entry,
 			_("SCSI target for the CD recorder. If this is non-empty it is "
-				"used instead of the scsibus/target/lun above. "
+				"used instead of the SCSI-bus/target/lun above. "
 				"(example: /dev/sga)"), NULL);
 
 	driver_label = gtk_label_new(_("Driver:"));
@@ -237,7 +250,7 @@ config_cdr_data *config_cdr(int config_flags) {
 	gtk_widget_show(vbox2);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox2, TRUE, FALSE, 0);
 
-	check_drive = gtk_button_new_with_label(_("Check scsi settings"));
+	check_drive = gtk_button_new_with_label(_("Check SCSI settings"));
 	gtk_widget_show(check_drive);
 	gtk_box_pack_start(GTK_BOX(vbox2), check_drive, TRUE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, check_drive,
@@ -249,12 +262,12 @@ config_cdr_data *config_cdr(int config_flags) {
 	gtk_widget_show(vbox2);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox2, TRUE, FALSE, 0);
 
-	auto_detect_drive = gtk_button_new_with_label(_("Detect scsi drive"));
+	auto_detect_drive = gtk_button_new_with_label(_("Detect SCSI drive"));
 	gtk_widget_show(auto_detect_drive);
 	gtk_box_pack_start(GTK_BOX(vbox2), auto_detect_drive, TRUE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, auto_detect_drive, _("Automaticaly locates "
+	gtk_tooltips_set_tip(tooltips, auto_detect_drive, _("Automatically locates "
 				"your drive, press multiple times to cycle through "
-				"scsi devices if you have more than one"), NULL);
+				"SCSI devices if you have more than one"), NULL);
 	gtk_signal_connect(GTK_OBJECT(auto_detect_drive),
 			"clicked", (GtkSignalFunc) cdrecord_auto_detect_drive, info);
 
@@ -283,7 +296,7 @@ config_cdr_data *config_cdr(int config_flags) {
 	return info;
 }
 
-void cursor_wait(GtkWidget *widget) {
+void cursor_wait(void) {
 	GdkCursor *cursor;
 
 	cursor = gdk_cursor_new(GDK_WATCH);
@@ -292,7 +305,7 @@ void cursor_wait(GtkWidget *widget) {
 	gdk_cursor_destroy(cursor);
 }
 
-void cursor_reset(GtkWidget *widget) {
+void cursor_reset(void) {
   gdk_window_set_cursor(mainwindow->window, NULL);
 }
 
