@@ -41,8 +41,10 @@ void set_notebook_tab(GtkWidget *, gint, GtkWidget *);
 void choose_path(GtkWidget *, gpointer);
 void alert_user_of_error(gchar *);
 void alert_user_of_error_msg(gchar *, gchar *);
+void alert_user_of_error_with_cb(gchar *, GtkSignalFunc);
+
 GtkWidget *make_frame(gchar *, gint);
 void close_dialog(GtkWidget *, gpointer);
 
-void cursor_wait(GtkWidget *);
-void cursor_reset(GtkWidget *);
+void cursor_wait(void);
+void cursor_reset(void);
