@@ -207,6 +207,11 @@ static void set_speed(char *s) {
 	l = strtol(s, (char **)NULL, 10);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(speed_spin), l);
 }
+static void set_grace_time(char *s) {
+	int l;
+	l = strtol(s, (char **)NULL, 10);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(grace_time_spin), l);
+}
 static void set_dummy(char *path) {
 	if (*(path) == '1')
 		misc_prefs.dummy = TRUE;
@@ -264,6 +269,9 @@ static void set_old_session(char *path) {
 static void set_completion_msg(char *path) {
 	misc_prefs.completion_msg = (*(path) == '1');
 }
+static void set_overburn(char *path) {
+	misc_prefs.overburn = (*(path) == '1');
+}
 
 static struct {
 	char *string;
@@ -291,6 +299,7 @@ static struct {
 	{"dev_isodevice=", set_isodevice},
 	{"dev_swab=", set_swab},
 	{"dev_speed=", set_speed},
+	{"dev_grace_time=", set_grace_time},
 	{"dummy=", set_dummy},
 	{"get_size=", set_get_size},
 	{"eject=", set_eject},
@@ -300,6 +309,7 @@ static struct {
 	{"burnproof=", set_burnproof},
 	{"disable_fixate=", set_disable_fixate},
 	{"completion_msg=", set_completion_msg},
+	{"overburn=", set_overburn},
 	{"set_old_session=", set_old_session}
 };
 
@@ -447,6 +457,7 @@ void save_config_file(config_cdr_data *cdr_info) {
 	fprintf(fp, "burnproof=%d\n", misc_prefs.burnproof);
 	fprintf(fp, "disable_fixate=%d\n", misc_prefs.disable_fixate);
 	fprintf(fp, "completion_msg=%d\n", misc_prefs.completion_msg);
+	fprintf(fp, "overburn=%d\n", misc_prefs.overburn);
 
 	fprintf (fp, "set_old_session=%s\n",misc_prefs.old_session);
 
@@ -465,6 +476,7 @@ void save_config_file(config_cdr_data *cdr_info) {
 		fprintf(fp, "dev_swab=0\n");
 
 	fprintf(fp, "dev_speed=%i\n", gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(speed_spin)));
+	fprintf(fp, "dev_grace_time=%i\n", gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(grace_time_spin)));
 
 	fclose(fp);
 }
