@@ -26,5 +26,5 @@ FILE *popen_r_stdout(cmd_v *);
 
 int *popen_re_unbuffered(cmd_v *);
 int *popen_r_err_in(cmd_v *, cmd_v *);
-char *my_basename(const char *);
-
+char *my_basename(char *);
+void my_strip_trailing_slashes(char *);
