@@ -39,9 +39,10 @@ static int last_row_selected = -1;
 
 GtkWidget *total_size, *exclude_pattern_combo, *clist, *exclude_dir;
 GtkWidget *mkisofs_follow_symlinks, *mkisofs_include_all, *mkisofs_include_dirname;
+GtkWidget *path_default_level_sb, *path_default_from_end;
 GList *exclude_pattern_list = NULL;
 
-long int totalsize, sectorsize;
+long long int totalsize, sectorsize;
 int selected_files[MAX_ROWS];
 
 void mark_size_inaccurate(void) {
@@ -103,24 +104,24 @@ static void connect_selsigs(GtkWidget *cl) {
 }
 
 static GtkWidget *create_toolbar(void) {
-	GtkWidget *toolbar, *add_file_tool, *del_selection_tool, *select_all_tool, *unselect_all_tool;
+	GtkWidget *toolbar;
 
 	toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_TEXT);
-	add_file_tool = gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), _("Add directory"),
+	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), _("Add directory"),
 			_("Opens file selector to let you add a file or directory. If you "
 				"want to add an entry starting with . (dot), write a . in the "
 				"name selection field of the file selector and press TAB"), "Private",
 			NULL, GTK_SIGNAL_FUNC(choose_file), (gpointer) selected_file);
 
-	del_selection_tool = gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), _("Del selected"),
+	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), _("Del selected"),
 			_("Deletes the selected files/directories"), "Private",
 			NULL, GTK_SIGNAL_FUNC(del_selected_rows), NULL);
 
-	select_all_tool = gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), _("Select all"),
+	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), _("Select all"),
 			_("Selects all files/directories"), "Private",
 			NULL, GTK_SIGNAL_FUNC(select_all), NULL);
 
-	unselect_all_tool = gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), _("Unselect all"),
+	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), _("Unselect all"),
 			_("Unselects all files/directories"), "Private",
 			NULL, GTK_SIGNAL_FUNC(unselect_all), NULL);
 
@@ -168,11 +169,7 @@ static void create_filelist(void) {
 	connect_selsigs(clist);
 	gtk_signal_connect(GTK_OBJECT(clist), "key_press_event",
 			GTK_SIGNAL_FUNC(clist_keypress), NULL);
-/*
-	gtk_signal_connect_after(GTK_OBJECT(mainwindow), "configure_event",
-			GTK_SIGNAL_FUNC(resize_clist_col_ratio), 
-			GTK_WIDGET(clist));
-*/
+
 	gtk_clist_set_column_auto_resize(GTK_CLIST(clist), 0, TRUE);
 
 	gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_MULTIPLE);
@@ -180,6 +177,10 @@ static void create_filelist(void) {
 
 static GtkWidget *create_button_area(config_cdr_data *cdr_info) {
 	GtkWidget *vbox, *recalc, *button_box;
+	GtkWidget *hbox, *label, *radiob;
+	GtkObject *spinb_adj;
+	GSList *rgroup = NULL;
+
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox);
@@ -209,7 +210,7 @@ static GtkWidget *create_button_area(config_cdr_data *cdr_info) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(mkisofs_follow_symlinks), TRUE);
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(mkisofs_follow_symlinks), TRUE);
 
-	mkisofs_include_dirname = gtk_check_button_new_with_label(_("Include dirname"));
+	mkisofs_include_dirname = gtk_check_button_new_with_label(_("Include dir name"));
 	gtk_widget_show(mkisofs_include_dirname);
 	gtk_signal_connect(GTK_OBJECT(mkisofs_include_dirname), "clicked",
 			GTK_SIGNAL_FUNC(toggle_dirname), 0);
@@ -218,7 +219,7 @@ static GtkWidget *create_button_area(config_cdr_data *cdr_info) {
 				"(if this option is disabled the _contents_ of the "
 				"directories added will appear at the root). NOTE: this "
 				"option currently has no effect when making sessions in "
-				"multisession mode."), NULL);
+				"multi session mode."), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox), mkisofs_include_dirname, FALSE, FALSE, 0);
 
 	gtk_widget_set_sensitive(mkisofs_include_dirname, TRUE);
@@ -230,7 +231,7 @@ static GtkWidget *create_button_area(config_cdr_data *cdr_info) {
 	gtk_signal_connect(GTK_OBJECT(mkisofs_include_all), "clicked",
 			GTK_SIGNAL_FUNC(toggle_incall), 0);
 	gtk_tooltips_set_tip(tooltips, mkisofs_include_all, _("Include "
-			"all files on the ISO 9660 filesystem; if turned off, filenames "
+			"all files on the ISO 9660 file system; if turned off, filenames "
 			"containing ~ or # or ending with .bak are excluded"), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox), mkisofs_include_all, FALSE, FALSE, 0);
 
@@ -240,6 +241,46 @@ static GtkWidget *create_button_area(config_cdr_data *cdr_info) {
 
 	optimize_attach(vbox);
 
+	label = gtk_label_new(_("Default pathlevel:"));
+	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+	gtk_widget_show(label);
+
+	hbox = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+
+	spinb_adj = gtk_adjustment_new(1, 0, 1000, 1, 10, 10);
+	path_default_level_sb = gtk_spin_button_new(GTK_ADJUSTMENT(spinb_adj), 1, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), path_default_level_sb, FALSE, FALSE, 0);
+	gtk_tooltips_set_tip(tooltips, path_default_level_sb, _("Number of pathcomponents to "
+				"ignore/include by default (depends on radiobutton setting bellow). "
+				"Note that this option takes effect only at the time you add "
+				"files/directories (e.g., add a file, change it to 2 and add another "
+				"file and you will see the difference)."),
+			NULL);
+
+	label = gtk_label_new(_(" levels"));
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+
+
+	gtk_widget_show_all(hbox);
+
+	radiob = gtk_radio_button_new_with_label(rgroup, _("Ignore from start"));
+	rgroup = gtk_radio_button_group(GTK_RADIO_BUTTON(radiob));
+	gtk_box_pack_start(GTK_BOX(vbox), radiob, FALSE, FALSE, 0);
+	gtk_tooltips_set_tip(tooltips, radiob, _("Strip N leading pathcomponents "
+				"from the paths added"), NULL);
+	gtk_widget_show_all(radiob);
+
+	radiob = gtk_radio_button_new_with_label(rgroup, _("Include from end"));
+	rgroup = gtk_radio_button_group(GTK_RADIO_BUTTON(radiob));
+	gtk_box_pack_start(GTK_BOX(vbox), radiob, FALSE, FALSE, 0);
+	gtk_tooltips_set_tip(tooltips, radiob, _("Include N pathcomponents from "
+				"the paths added (1 is the default behaviour, 0 "
+				"means include all)"), NULL);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiob), TRUE);
+	gtk_widget_show_all(radiob);
+	path_default_from_end = radiob;
+
 	return vbox;
 }
 
@@ -380,16 +421,16 @@ static void dropped_data(GtkWidget *widget, GdkDragContext *context, gint x, gin
 				return;
 		}
 
-		cursor_wait(NULL);
+		cursor_wait();
 		mainwindow_disable_tabs();
 		while (names) {
-			selected_file(0, (gchar *)names->data);
+			add_path_to_files((gchar *)names->data);
 			names = names->next;
 			while (gtk_events_pending()) gtk_main_iteration_do(0);
 		}
 		mainwindow_enable_tabs();
 		gnome_uri_list_free_strings(list);
-		cursor_reset(NULL);
+		cursor_reset();
 	} else {
 		g_message("%s %i: unknown type dropped, should not happen!",
 				__FILE__, __LINE__);
