@@ -21,7 +21,7 @@ typedef struct {
 	char *newline; /* last recently extracted line */
 } linebuffer;
 
-char *string_append(char *, char *);
+char *string_append(char *, const char *);
 int extract_line(linebuffer *, char *);
 void add_to_buffer(linebuffer *, char *);
 void init_buffer(linebuffer *);
