@@ -16,7 +16,7 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-GtkWidget *enable_multisession, *force_data_multisession, *old_session, *enable_cdplus;
+extern GtkWidget *enable_multisession, *force_data_multisession, *old_session, *enable_cdplus;
 
 void multisession_options(GtkWidget *);
 int check_blank_disk(void);
