@@ -33,7 +33,8 @@ options mkisofs_options[] = {
 	{NULL, "-r", N_("Anonymous Rock Ridge"), N_("File ownership and modes are set to useful values; uid/guid set to zero, all files are set readable and write bits/special mode bits are cleared"), TRUE},
 	{NULL, "-l", N_("Allow 32 char filenames"), N_("Allow full 32 character filenames - may cause problems if disc intended for use in MS-DOS systems"), TRUE},
 	{NULL, "-J", N_("Joliet extension"), N_("Generate Joliet directory records in addition to regular ISO 9660 file names, useful if disc to be used with Win9X/NT machines (gives you long filenames)"), TRUE},
-	{NULL, "-T", N_("Generate TRANS.TBL files"), N_("Generate a file TRANS.TBL in each directory on the CDROM, which can be used on non-Rock Ridge capable systems to help establish the correct file names."), FALSE}
+	{NULL, "-T", N_("Generate TRANS.TBL files"), N_("Generate a file TRANS.TBL in each directory on the CD-ROM, which can be used on non-Rock Ridge capable systems to help establish the correct file names."), FALSE},
+	{NULL, "-udf", N_("UDF extension"), N_("Include UDF support in the generated filesystem (e.g., for DVD Media)."), FALSE}
 };
 
 options mkisofs_special_options[] = {
@@ -44,13 +45,14 @@ options mkisofs_special_options[] = {
 	{NULL, NULL, N_("Bootable CD"), N_("Create a \"El Torito\" bootable CD, you also need to fill in the boot image and catalog below"), FALSE},
 	{NULL, "-U", N_("Allow untranslated filenames"), N_("Allows untranslated file names (for example, that have more than one dot (.) in file name). Completely violates ISO 9660. Use with caution."), FALSE},
 	{NULL, "-hide-rr-moved", N_("Hide rr_moved"), N_("Rename the directory RR_MOVED to .rr_moved in the Rock Ridge tree."), FALSE},
-	{NULL, "-no-rr", N_("No RR"), N_("Do not use the Rock Ridge attributes from previous sessions. This may allow mkisofs to work with multisession CDs with broken Rock Ridge signatues on the old sessions."), FALSE}
+	{NULL, "-no-rr", N_("No RR"), N_("Do not use the Rock Ridge attributes from previous sessions. This may allow mkisofs to work with multi session CDs with broken Rock Ridge signatures on the old sessions."), FALSE},
+	{NULL, "-dvd-video", N_("Generate DVD-Video Compatible UDF file system"), N_("Fixes file ordering for DVD Video Players"), FALSE}
 };
 
 options mkisofs_text_options[] = {
 	{NULL, "-V", N_("Volume id: "), N_("Specifies the volume ID to be written into the master block."), FALSE},
 	{NULL, "-A", N_("Application id: "), N_("This should describe the application that will be on the disc."), FALSE},
-	{NULL, "-P", N_("Publisher id: "), N_("This should describe the publisher of the CDROM, usually with a mailing address and phone number."), FALSE}
+	{NULL, "-P", N_("Publisher id: "), N_("This should describe the publisher of the CD-ROM, usually with a mailing address and phone number."), FALSE}
 };
 
 options mkhybrid_options[] = {
@@ -60,9 +62,13 @@ options mkhybrid_options[] = {
 	{NULL, "-netatalk", N_("netatalk"), N_("Look for NETATALK Macintosh files"), FALSE}
 };
 
+options mkhybrid_text_options[] = {
+	{NULL, "-auto", N_("Autostart"), N_("A filename in the root of an HFS CD to use for the QuickTime 2.0 Autostart feature to launch an application or document."), FALSE}
+};
+
 options torito_options[] = {
-	{NULL, "-b", N_("Boot image: "), N_("Specifies the path/filename of the boot image to be used. The path to the image should be specified relatively to the generated file tree (ie if you add a directory 'disks' with the bootimage 'rescue.bin' inside in the Data files tab, you will end up with the bootfile 'disks/rescue.bin' in the generated image, so you should put 'disks/rescue.bin' here)"), FALSE},
-	{NULL, "-c", N_("Boot catalog: "), N_("Specifies the path/filename of the boot catalog to be used. This should be specified in the same manner as above (eg 'disks/boot.catalog'). Note that this file will be inserted by mkisofs in the target filesystem, so it should not conflict with an existing file!"), FALSE},
+	{NULL, "-b", N_("Boot image: "), N_("Specifies the path/filename of the boot image to be used. The path to the image should be specified relatively to the generated file tree (ie if you add a directory 'disks' with the boot image 'rescue.bin' inside in the Data files tab, you will end up with the boot file 'disks/rescue.bin' in the generated image, so you should put 'disks/rescue.bin' here)"), FALSE},
+	{NULL, "-c", N_("Boot catalog: "), N_("Specifies the path/filename of the boot catalog to be used. This should be specified in the same manner as above (eg 'disks/boot.catalog'). Note that this file will be inserted by mkisofs in the target file system, so it should not conflict with an existing file!"), FALSE},
 };
 
 static GtkWidget *table;
@@ -70,20 +76,14 @@ static GtkWidget *table;
 static void torito_set_in_use(GtkWidget *widget, gpointer data) {
 	unsigned int i;
 
-	if (GTK_TOGGLE_BUTTON(mkisofs_special_options[4].widget)->active)
-		for (i = 0; i < sizeof(torito_options)/sizeof(options); i++)
-			gtk_widget_set_sensitive(torito_options[i].widget, FALSE);
-	else
-		for (i = 0; i < sizeof(torito_options)/sizeof(options); i++)
-			gtk_widget_set_sensitive(torito_options[i].widget, TRUE);
+	for (i = 0; i < sizeof(torito_options)/sizeof(options); i++)
+		gtk_widget_set_sensitive(torito_options[i].widget,
+				GTK_TOGGLE_BUTTON(mkisofs_special_options[4].widget)->active);
 }
-
-static void mkh_deselect_hfs(GtkWidget *widget, gpointer data) {
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(mkhybrid_options[1].widget), FALSE);
-}
-
-static void mkh_deselect_apple(GtkWidget *widget, gpointer data) {
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(mkhybrid_options[2].widget), FALSE);
+static void hfs_set_in_use(GtkWidget *widget, gpointer data) {
+	gtk_widget_set_sensitive(mkhybrid_text_options[0].widget,
+			GTK_TOGGLE_BUTTON(mkhybrid_options[0].widget)->active
+			| GTK_TOGGLE_BUTTON(mkhybrid_options[1].widget)->active);
 }
 
 /* add the i:th check-button to it's place in the table of width TABLE_WIDTH */
@@ -130,7 +130,7 @@ void create_options(GtkWidget *tab) {
 	gtk_container_add(GTK_CONTAINER(tab), vbox);
 
 	/* option frames */
-	frame = make_frame(_("General filesystem options"), 5);
+	frame = make_frame(_("General file system options"), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, TRUE, 0);
 
 	table = gtk_table_new(3, TABLE_WIDTH, FALSE);
@@ -155,23 +155,26 @@ void create_options(GtkWidget *tab) {
 	frame = make_frame(_("HFS options"), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, TRUE, 0);
 
+	vbox2 = gtk_vbox_new(FALSE, 0);
+	gtk_widget_show(vbox2);
+	gtk_container_add(GTK_CONTAINER(frame), vbox2);
+
 	table = gtk_table_new(3, TABLE_WIDTH, FALSE);
 	gtk_widget_show(table);
-	gtk_container_add(GTK_CONTAINER(frame), table);
+	gtk_container_add(GTK_CONTAINER(vbox2), table);
 
 	for (i = 0; i < (sizeof(mkhybrid_options)/sizeof(options)); i++) {
 		add_checkb(i, mkhybrid_options);
 	}
-/*
-	gtk_signal_connect(GTK_OBJECT(mkhybrid_options[0].widget),
-			"button_release_event",
-			GTK_SIGNAL_FUNC(mkh_set_in_use), 0); */
-	gtk_signal_connect(GTK_OBJECT(mkhybrid_options[0].widget),
-			"button_release_event",
-			GTK_SIGNAL_FUNC(mkh_deselect_apple), 0);
-	gtk_signal_connect(GTK_OBJECT(mkhybrid_options[1].widget),
-			"button_release_event",
-			GTK_SIGNAL_FUNC(mkh_deselect_hfs), 0);
+
+	for (i = 0; i < (sizeof(mkhybrid_text_options)/sizeof(options)); i++)
+		add_entry(vbox2, i, mkhybrid_text_options);
+	gtk_entry_set_max_length(GTK_ENTRY(mkhybrid_text_options[0].widget), 11);
+	gtk_widget_set_sensitive(mkhybrid_text_options[0].widget, FALSE);
+	gtk_signal_connect(GTK_OBJECT(mkhybrid_options[0].widget), "clicked",
+			GTK_SIGNAL_FUNC(hfs_set_in_use), GINT_TO_POINTER(0));
+	gtk_signal_connect(GTK_OBJECT(mkhybrid_options[1].widget), "clicked",
+			GTK_SIGNAL_FUNC(hfs_set_in_use), GINT_TO_POINTER(1));
 
 	frame = make_frame(_("Name options"), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, TRUE, 0);
@@ -182,6 +185,7 @@ void create_options(GtkWidget *tab) {
 
 	for (i = 0; i < (sizeof(mkisofs_text_options)/sizeof(options)); i++)
 		add_entry(vbox2, i, mkisofs_text_options);
+	gtk_entry_set_max_length(GTK_ENTRY(mkisofs_text_options[0].widget), 32);
 
 	frame = make_frame(_("\"El Torito\" bootable CD options"), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, TRUE, 0);
@@ -194,7 +198,7 @@ void create_options(GtkWidget *tab) {
 		add_entry(vbox2, i, torito_options);
 
 	gtk_signal_connect(GTK_OBJECT(mkisofs_special_options[4].widget),
-			"button_release_event",
+			"clicked",
 			GTK_SIGNAL_FUNC(torito_set_in_use), 0);
 /* FIXME: same as above */
 	for (i = 0; i < sizeof(torito_options)/sizeof(options); i++)
