@@ -221,7 +221,7 @@ static int handle_cd_to_file_results(gpointer data) {
 	if ((status.written == status.image_size) && (0 != status.written)) {
 		char *m;
 		char b[NUM_BUF];
-		m = string_append(_(" Copying of cd image to disk compelete! \n "), NULL);
+		m = string_append(_(" Copying of cd image to disk complete! \n "), NULL);
 		g_snprintf(b, NUM_BUF, "%ld", status.written);
 		m = string_append(m, b);
 		m = string_append(m, " bytes copied. ");
