@@ -41,6 +41,8 @@ static linebuffer cdrecord_stderr, cdrecord_stdout, mkisofs_stderr, mkisofs_stdo
 
 static int frozen, total_track_size, total_track_written, current_track_size;
 
+/* TODO: countdown_counter shouldn't be used, we should read the info from
+ * cdrecord (e.g., this breaks if gracetime=2 is used) */
 static void do_countdown(int starting) {
 
 	estimate_finnish_time_start();
@@ -340,6 +342,10 @@ static void add_cdrecord_stderr_output(int *status, int check_for_end) {
 		*status = FALSE;
 	} else if (strstr(cdrecord_stderr.newline, "cdrecord: Cannot send CUE sheet.")) {
 		*status = FALSE;
+	} else if (strstr(cdrecord_stderr.newline, "WRa Data")) {
+		/* drv_jvc.c in cdrecord prints out a lot of this, but I have
+		 * no idea what it is*/
+		return;
 	}
 	if (!frozen) {
 		gtk_text_freeze(GTK_TEXT(cdrecord_text));
@@ -377,6 +383,11 @@ int ni_read_cdrecord_stderr(int fd, int check_for_end) {
 	return status;
 }
 
+static void disk_reloaded(GtkWidget *widget, gpointer data) {
+	/* yes, now all we need is a way to tell cdrecord about this */
+	alert_user_of_error("Not yet implemented");
+}
+
 static int add_cdrecord_stdout_output(void) {
 	/*		if (strstr(cdrecord_stdout.newline, "Writing  time:"))
 			{}
@@ -398,43 +409,56 @@ static int add_cdrecord_stdout_output(void) {
 		do_countdown(1);
 		estimate_finnish_time_start();
 	} else if (strstr(cdrecord_stdout.newline, "Track ")
-			&& strstr(cdrecord_stdout.newline, " MB written (fifo ")) {
+			&& strstr(cdrecord_stdout.newline, " MB written ")) {
 		if (mkisofs_stderr.buffer == NULL) {
 			/* mkisofs isn't running, update progressbar */
-			float written, left;
-			if (strlen(cdrecord_stdout.newline) <= 20) {
-				g_warning("%s::%i: incompatible output from cdrecord, this is a bug", __FILE__, __LINE__);
-				return TRUE;
-			}
-			cdrecord_stdout.newline[13] = 0;
-			cdrecord_stdout.newline[20] = 0;
-			if (GTK_TOGGLE_BUTTON(audio_tracks)->active) {
-				written = atof(&cdrecord_stdout.newline[9]);
-				written += total_track_written;
-				current_track_size = atof(&cdrecord_stdout.newline[16]);
-				left = (float)(total_track_size + current_track_size);
-			} else {
-				written = atof(&cdrecord_stdout.newline[9]);
-				left = atof(&cdrecord_stdout.newline[16]);
-			}
-			if ((0 == left) || (written / left < 0) || (written / left > 1))
-				g_warning("%s::%i: add_cdrecord_stdout_output estimated finish error: "
-						"written: %f left: %f", __FILE__, __LINE__, written, left);
-			else {
-				gtk_progress_bar_update(GTK_PROGRESS_BAR(progress_bar),
-						written/left);
-				estimate_finnish_time_update(written/left);
-			}
+			char *end;
+			/* old cdrecord: "Track 00:   0 of   0 MB"   or "Track 00:   0 MB" */
+			/* new cdrecord: "Track 00:    0 of    0 MB" or "Track 00:    0 MB" */
+			/* " written" */
+
+			/* Track XX: */
 			cdrecord_stdout.newline[8] = 0;
 			set_track_burning_now(atoi(&cdrecord_stdout.newline[6]));
 			cdrecord_stdout.newline[8] = ' ';
-			cdrecord_stdout.newline[13] = ' ';
-			cdrecord_stdout.newline[20] = ' ';
+
+			/* "  XX of "*/
+			if (NULL != (end = strstr(cdrecord_stdout.newline, " of "))) {
+				/* can't update the progress bar unless we get the total file size */
+				float written, total;
+				char *mb_end;
+				*end = 0;
+				written = atof(&cdrecord_stdout.newline[9]);
+				*end = ' ';
+
+				/* "  XX MB " */
+				mb_end = strstr(cdrecord_stdout.newline, " MB ");
+				*mb_end = 0;
+				total = atof(end + 3);
+				*mb_end = ' ';
+
+				if (GTK_TOGGLE_BUTTON(audio_tracks)->active) {
+					written += total_track_written;
+					current_track_size = total;
+					total = (float)(total_track_size);
+				}
+				if ((0 == total) || (written / total < 0) || (written / total > 1))
+					g_warning("%s::%i: add_cdrecord_stdout_output estimated finish error: "
+							"written: %f total: %f", __FILE__, __LINE__, written, total);
+				else {
+					gtk_progress_bar_update(GTK_PROGRESS_BAR(progress_bar),
+							written/total);
+					estimate_finnish_time_update(written/total);
+				}
+			}
 		}
 		set_mb_fifo_info(&cdrecord_stdout.newline[9]);
-	} else if (strstr(cdrecord_stdout.newline, "Last chance to quit, starting "))
+	} else if (strstr(cdrecord_stdout.newline, "Last chance to quit, starting ")) {
+		char *s = strstr(cdrecord_stdout.newline, " write in ");
+		if (NULL != s)
+			countdown_counter = atoi(s+9);
 		do_countdown(0);
-	else if (strstr(cdrecord_stdout.newline, " seconds.")
+	} else if (strstr(cdrecord_stdout.newline, " seconds.")
 			&& !(strstr(cdrecord_stdout.newline, "ATAPI early return: sleeping")))
 		do_countdown(0);
 	else if (strstr(cdrecord_stdout.newline, "Blanking "))
@@ -443,6 +467,8 @@ static int add_cdrecord_stdout_output(void) {
 		total_track_written += current_track_size;
 	else if (strstr(cdrecord_stdout.newline, "Total size:"))
 		total_track_size = atoi(&cdrecord_stdout.newline[strlen("Total size: ")]);
+	else if (strstr(cdrecord_stdout.newline, "Re-load disk and hit <CR>"))
+		alert_user_of_error_with_cb(_("Re-load disk and press OK"), &disk_reloaded);
 	else {
 		if (!frozen) {
 			gtk_text_freeze(GTK_TEXT(cdrecord_text));
@@ -468,6 +494,7 @@ int ni_read_cdrecord_stdout(int fd) {
 	 *        changing add_cdrecord_stdout_output as well */
 	while (extract_line(&cdrecord_stdout, "\n")
 			|| extract_line(&cdrecord_stdout, "\r")
+			|| extract_line(&cdrecord_stdout, "\b")
 			|| extract_line(&cdrecord_stdout, " seconds.")) /* countdown */ {
 		if (FALSE == add_cdrecord_stdout_output()) {
 			if (frozen) {
