@@ -18,6 +18,6 @@
 
 void open_rip_audio_req(void);
 
-extern char *cdda2wav_path, *cdda_device_path;
+extern char *cdda2wav_path, *cdda_device_path, *cdparanoia_path;
 extern char *def_rip_path;
 extern GtkWidget *rip_path_entry;
